#[repr(C)]pub enum NumaMemoryPolicy {
NodeLocalStrict = 1,
NodeLocalLeniant = 2,
}Variants
NodeLocalStrict = 1
Allocates from local node; fails if no memory is available in local node
NodeLocalLeniant = 2
Allocates from local node; falls back to allocating from other nodes in the increasing order of distance from the current node