#[repr(C)]pub struct Map {
pub offset: usize,
pub size: usize,
pub flags: MapFlags,
pub address: usize,
}Fields
offset: usizeThe offset inside the file that is being mapped.
size: usizeThe size of the memory map.
flags: MapFlagsContains both prot and map flags.
address: usizeFunctions as a hint to where in the virtual address space of the running process, to place
the memory map. If MapFlags::MAP_FIXED is set, then this address must be the address to
map to.