Struct syscall::flag::MapFlags [−][src]
pub struct MapFlags { /* fields omitted */ }Implementations
impl MapFlags[src]
impl MapFlags[src]pub const PROT_NONE: MapFlags[src]
pub const PROT_EXEC: MapFlags[src]
pub const PROT_WRITE: MapFlags[src]
pub const PROT_READ: MapFlags[src]
pub const MAP_SHARED: MapFlags[src]
pub const MAP_PRIVATE: MapFlags[src]
pub const MAP_FIXED: MapFlags[src]
Only accepted for mmap2(2).
pub const MAP_FIXED_NOREPLACE: MapFlags[src]
pub const fn empty() -> MapFlags[src]
Returns an empty set of flags
pub const fn all() -> MapFlags[src]
Returns the set containing all flags.
pub const fn bits(&self) -> usize[src]
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: usize) -> Option<MapFlags>[src]
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: usize) -> MapFlags[src]
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: usize) -> MapFlags[src]
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn is_empty(&self) -> bool[src]
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool[src]
Returns true if all flags are currently set.
pub const fn intersects(&self, other: MapFlags) -> bool[src]
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: MapFlags) -> bool[src]
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: MapFlags)[src]
Inserts the specified flags in-place.
pub fn remove(&mut self, other: MapFlags)[src]
Removes the specified flags in-place.
pub fn toggle(&mut self, other: MapFlags)[src]
Toggles the specified flags in-place.
pub fn set(&mut self, other: MapFlags, value: bool)[src]
Inserts or removes the specified flags depending on the passed value.