#[repr(packed)]
pub struct Mmio<T> { /* fields omitted */ }
👎 Deprecated:
unsound because it’s possible to read even though it’s uninitialized
Create a new Mmio without initializing
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.