macro_rules! syscall {
($fn: ident ( $($arg: expr),* $(,)* ) ) => { ... };
}Expand description
System call wrapper.
Wrapper around libc system calls that checks errno on failure.
macro_rules! syscall {
($fn: ident ( $($arg: expr),* $(,)* ) ) => { ... };
}System call wrapper.
Wrapper around libc system calls that checks errno on failure.