CqeOpcode

Enum CqeOpcode 

#[repr(u8)]
pub enum CqeOpcode { RespondRegular = 0, RespondWithFd = 1, SendFevent = 2, ObtainFd = 3, RespondWithMultipleFds = 4, RespondAndNotifyOnDetach = 5, }

Variants



RespondRegular = 0



RespondWithFd = 1



SendFevent = 2



ObtainFd = 3



RespondWithMultipleFds = 4



RespondAndNotifyOnDetach = 5

[SchemeAsync::on_close] and [SchemeSync::on_close] are only called when the last file descriptor referring to the file description is closed. To implement traditional POSIX advisory file locking, CqeOpcode::RespondAndNotifyOnDetach is used to notify the scheme by sending a [RequestKind::OnDetach] request the next time the file description is “detached” from a file descriptor. Not done by default to avoid unnecessary IPC.

Implementations

Source

impl CqeOpcode

pub fn try_from_raw(raw: u8) -> Option<Self>