[−][src]Module syscall::flag
Flags used as an argument to many system calls
Constants
Functions
| wcoredump | True if status indicates a core dump was created. |
| wexitstatus | If wifexited(status), the exit status. |
| wifcontinued | True if status indicates the child continued after a stop. |
| wifexited | True if status indicates normal termination. |
| wifsignaled | True if STATUS indicates termination by a signal. |
| wifstopped | True if status indicates the child is stopped. |
| wstopsig | If wifstopped(status), the signal that stopped the child. |
| wtermsig | If wifsignaled(status), the terminating signal. |