#[repr(packed)]
pub struct Mmio<T> { /* fields omitted */ }
pub fn new() -> Self[src]
👎 Deprecated:
unsound because it’s possible to read even though it’s uninitialized
Create a new Mmio without initializing
pub unsafe fn zeroed() -> Self[src]
pub unsafe fn uninit() -> Self[src]
pub const fn from(value: T) -> Self[src]
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.